jacinle.nd.batch
================

.. automodule:: jacinle.nd.batch

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      batchify
      unbatchify
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: batchify

.. autofunction:: unbatchify


